###DOmake.ins.page.plots - creates 24hr profile ps plot file of INS data
##
## smsmith Mar96 mlvl62 - based on DOmake.imet.page.plot
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.

if ($#argv < 1) then
   echo "usage: DOmake.ins.page.plot   <date.ext>"
   echo " (produces postscript file named ins_1min_summary.<date.ext>.ps)"
   exit
endif

set DATE = $1

if   ( -e $DIRUWDATA/NAV/CS_SPinpf.$DATE.Z) then
   setenv CAT zcat
else if ( -e $DIRUWDATA/NAV/CS_SPinpf.$DATE) then
   setenv CAT cat
else
   echo "DOmake.ins.page.plot: Missing input data file"
   exit
endif

# Change these Lower/Upper ranges as necessary:
set LATD_RANGE     = -40/+0      ; set LATD_TIC     = "a20g20:latitude:"
set LOND_RANGE     = +100/+180    ; set LOND_TIC     = "a20g20:longitude:"
set H2OTEMP_RANGE = 15/30         ; set H2OTEMP_TIC = "a10g5f1:h2o temp C.:"

# Don't change these:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"
set SPD_RANGE      = 0/16         ; set SPD_TIC      = "4g4:speed, knots:"
set HEADING_RANGE  = 0/360        ; set HEADING_TIC  = "a90g90:ship heading:"

set PRINTr = $LPDEST

cd $DIRUWDATA/NAV

set IFN = ins_1min_summary.$DATE

# extract INS values at 1 minute intervals

$CAT $DIRUWDATA/NAV/CS_SPinpf.$DATE | \
awk '{  \
 if(substr($0,15,2) == "00") {  \
	hrdec = substr($0,11,2) + substr($0,13,2)/60. \
	latdec = substr($0,24,2) + substr($0,27,6)/60. \
	if (substr($0,33,1) == "S"){latdec = -latdec} \
	londec = substr($0,34,3) + substr($0,38,6)/60. \
	if (substr($0,44,1) == "W"){londec = -londec} \
	spd = substr($0,53,5) \
	head = substr($0,59,5) \
	h2otemp = substr($0,65,5) \
	print hrdec,latdec,londec,spd,head,h2otemp \
        } \
     }'  >! $IFN


if !( -e $IFN ) then
   echo Cannot find file $IFN \!  Exiting...
   exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = $IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.5
   set XOFF1 = 1.2 ; set YOFF1 =  8.5
   set XOFF2 = 0.0 ; set YOFF2 = -1.9
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "INS data  $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

set COL_HR = 1       ; set COL_LATD = 2      ; set COL_LOND = 3
set COL_SPD = 4    ; set COL_HEADING = 5  ; set COL_H2OTEMP = 6

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`



###################### start 1st panel ######################################
set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/"$LATD_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$LATD_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_LATD
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$LOND_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$LOND_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_LOND
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

###################### start 3rd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$HEADING_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$HEADING_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_HEADING
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

###################### start 4th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$SPD_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$SPD_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_SPD
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

###################### start 5th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$H2OTEMP_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$H2OTEMP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_H2OTEMP
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

#psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
psbasemap   >> $OFN -R -JX -O -K -U/-0.5/-0.5/ `echo "$OPT"` -B"$TIC"
###################### end panel ############################################

pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
### finish off the postscript file ##########################################

#print the plot: copies for dproc, SCG, Lab
repeat 1 lp -s -d$PRINTr $OFN

/bin/rm -f $IFN
#end
